==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescription } from "./WebRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
var WebRowSelectorTemplateDetailsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowSelectorTemplateDetailsDescriptionMetadata, _super);
    function WebRowSelectorTemplateDetailsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectorTemplateDetailsDescriptionMetadata.b = function (a) {
        if (WebRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
            WebRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectorTemplateDetailsDescriptionMetadata.c(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
        if (a.j(WebRowSelectorTemplateDetailsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebRowSelectorTemplateDetailsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowSelectorTemplateDetails");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Index", "Number:double");
        a.item("RowID", "Unknown");
        a.item("Key", "Unknown");
        a.item("Selected", "Boolean");
    };
    WebRowSelectorTemplateDetailsDescriptionMetadata.d = function (a) {
        WebRowSelectorTemplateDetailsDescriptionMetadata.b(a);
        a.aa("WebRowSelectorTemplateDetails", function () { return new WebRowSelectorTemplateDetailsDescription(); });
        a.z("WebRowSelectorTemplateDetails", WebRowSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebRowSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebRowSelectorTemplateDetailsDescriptionMetadata, 'WebRowSelectorTemplateDetailsDescriptionMetadata');
    WebRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebRowSelectorTemplateDetailsDescriptionMetadata;
}(Base));
export { WebRowSelectorTemplateDetailsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectorTemplateDetailsDescription } from "./WebRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
var WebRowSelectorTemplateDetailsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowSelectorTemplateDetailsDescriptionMetadata, _super);
    function WebRowSelectorTemplateDetailsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectorTemplateDetailsDescriptionMetadata.b = function (a) {
        if (WebRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
            WebRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectorTemplateDetailsDescriptionMetadata.c(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
        if (a.k(WebRowSelectorTemplateDetailsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebRowSelectorTemplateDetailsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowSelectorTemplateDetails");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Index", "Number:double");
        a.item("RowID", "Unknown");
        a.item("Key", "Unknown");
        a.item("Selected", "Boolean");
    };
    WebRowSelectorTemplateDetailsDescriptionMetadata.d = function (a) {
        WebRowSelectorTemplateDetailsDescriptionMetadata.b(a);
        a.ac("WebRowSelectorTemplateDetails", function () { return new WebRowSelectorTemplateDetailsDescription(); });
        a.ab("WebRowSelectorTemplateDetails", WebRowSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebRowSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebRowSelectorTemplateDetailsDescriptionMetadata, 'WebRowSelectorTemplateDetailsDescriptionMetadata');
    WebRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebRowSelectorTemplateDetailsDescriptionMetadata;
}(Base));
export { WebRowSelectorTemplateDetailsDescriptionMetadata };
